@@ -2,8 +2,9 @@ import pytest
 
 import appmap
 import appmap.wrapt as wrapt
-
 from appmap._implementation import testing_framework
+from appmap._implementation.detect_enabled import DetectEnabled
+
 
 class recorded_testcase:
     def __init__(self, item):
@@ -13,18 +14,19 @@ class recorded_testcase:
     def __call__(self, wrapped, _, args, kwargs):
         item = self.item
         with item.session.appmap.record(
-                item.cls,
-                item.name,
-                method_id=item.originalname,
-                location=item.location) as metadata:
+            item.cls, item.name, method_id=item.originalname, location=item.location
+        ) as metadata:
             with testing_framework.collect_result_metadata(metadata):
                 return wrapped(*args, **kwargs)
 
 
-if appmap.enabled():
+if not DetectEnabled.is_appmap_repo() and DetectEnabled.should_enable("pytest"):
+
     @pytest.hookimpl
     def pytest_sessionstart(session):
-        session.appmap = testing_framework.session(name='pytest', version=pytest.__version__)
+        session.appmap = testing_framework.session(
+            name="pytest", recorder_type="tests", version=pytest.__version__
+        )
 
     @pytest.hookimpl
     def pytest_runtest_call(item):
@@ -46,21 +48,24 @@ if appmap.enabled():
         # running the test case. (This nesting of function calls is
         # verified by the expected appmap in the test for a unittest
         # TestCase run by pytest.)
-        if hasattr(item, '_testcase'):
-            setattr(item._testcase, '_appmap_pytest_recording', True) # pylint: disable=protected-access
+        if hasattr(item, "_testcase"):
+            setattr(
+                item._testcase, "_appmap_pytest_recording", True
+            )  # pylint: disable=protected-access
             item.obj = recorded_testcase(item)(item.obj)
 
     @pytest.hookimpl(hookwrapper=True)
     def pytest_pyfunc_call(pyfuncitem):
         # There definitely shouldn't be a `_testcase` attribute on a
         # pytest test.
-        assert not hasattr(pyfuncitem, '_testcase')
+        assert not hasattr(pyfuncitem, "_testcase")
 
         with pyfuncitem.session.appmap.record(
-                pyfuncitem.cls,
-                pyfuncitem.name,
-                method_id=pyfuncitem.originalname,
-                location=pyfuncitem.location) as metadata:
+            pyfuncitem.cls,
+            pyfuncitem.name,
+            method_id=pyfuncitem.originalname,
+            location=pyfuncitem.location,
+        ) as metadata:
             result = yield
             try:
                 with testing_framework.collect_result_metadata(metadata):
