@@ -1,12 +1,12 @@
-from operator import itemgetter
+import json
 import platform
 import re
+from operator import itemgetter
 
-import json
 import pytest
 
 import appmap._implementation
-from appmap._implementation.recording import Recorder
+from appmap._implementation.recorder import Recorder
 
 
 def normalize_path(path):
@@ -24,47 +24,42 @@ class AppMapTestBase:
     @staticmethod
     @pytest.fixture
     def events():
-        """Enables appmap recording and allows examining events."""
-        rec = Recorder()
-        rec.events.clear()
-        rec.enabled = True
-        yield rec.events
-        rec.enabled = False
-        rec.events.clear()
+        rec = Recorder.get_current()
+        rec.clear()
+        rec._enabled = True
+        return rec.events
 
     @staticmethod
     def normalize_git(git):
-        git.pop('repository')
-        git.pop('branch')
-        git.pop('commit')
-        status = git.pop('status')
+        git.pop("repository")
+        git.pop("branch")
+        git.pop("commit")
+        status = git.pop("status")
         assert isinstance(status, list)
-        tag = git.pop('tag', None)
+        tag = git.pop("tag", None)
         if tag:
             assert isinstance(tag, str)
-        commits_since_tag = git.pop('commits_since_tag', None)
+        commits_since_tag = git.pop("commits_since_tag", None)
         if commits_since_tag:
             assert isinstance(commits_since_tag, int)
-        git.pop('annotated_tag', None)
+        git.pop("annotated_tag", None)
 
-        commits_since_annotated_tag = git.pop(
-            'commits_since_annotated_tag', None
-        )
+        commits_since_annotated_tag = git.pop("commits_since_annotated_tag", None)
         if commits_since_annotated_tag:
             assert isinstance(commits_since_annotated_tag, int)
 
     @staticmethod
     def normalize_metadata(metadata):
-        engine = metadata['language'].pop('engine')
+        engine = metadata["language"].pop("engine")
         assert engine == platform.python_implementation()
-        version = metadata['language'].pop('version')
+        version = metadata["language"].pop("version")
         assert version == platform.python_version()
 
-        if 'frameworks' in metadata:
-            frameworks = metadata['frameworks']
+        if "frameworks" in metadata:
+            frameworks = metadata["frameworks"]
             for f in frameworks:
-                if f['name'] == 'pytest':
-                    v = f.pop('version')
+                if f["name"] == "pytest":
+                    v = f.pop("version")
                     assert v == pytest.__version__
 
     def normalize_appmap(self, generated_appmap):
@@ -77,33 +72,33 @@ class AppMapTestBase:
         """
 
         def normalize(dct):
-            if 'classMap' in dct:
-                dct['classMap'].sort(key=itemgetter('name'))
-            if 'children' in dct:
-                dct['children'].sort(key=itemgetter('name'))
-            if 'elapsed' in dct:
-                elapsed = dct.pop('elapsed')
+            if "classMap" in dct:
+                dct["classMap"].sort(key=itemgetter("name"))
+            if "children" in dct:
+                dct["children"].sort(key=itemgetter("name"))
+            if "elapsed" in dct:
+                elapsed = dct.pop("elapsed")
                 assert isinstance(elapsed, float)
-            if 'git' in dct:
-                self.normalize_git(dct.pop('git'))
-            if 'location' in dct:
-                dct['location'] = normalize_path(dct['location'])
-            if 'path' in dct:
-                dct['path'] = normalize_path(dct['path'])
-            if 'metadata' in dct:
-                self.normalize_metadata(dct['metadata'])
-            if 'object_id' in dct:
-                object_id = dct.pop('object_id')
+            if "git" in dct:
+                self.normalize_git(dct.pop("git"))
+            if "location" in dct:
+                dct["location"] = normalize_path(dct["location"])
+            if "path" in dct:
+                dct["path"] = normalize_path(dct["path"])
+            if "metadata" in dct:
+                self.normalize_metadata(dct["metadata"])
+            if "object_id" in dct:
+                object_id = dct.pop("object_id")
                 assert isinstance(object_id, int)
-            if 'value' in dct:
+            if "value" in dct:
                 # This maps all object references to the same
                 # location. We don't actually need to verify that the
                 # locations are correct -- if they weren't, the
                 # instrumented code would be broken, right?
-                v = dct['value']
-                dct['value'] = re.sub(r'<(.*) object at 0x.*>',
-                                      r'<\1 object at 0xabcdef>',
-                                      v)
+                v = dct["value"]
+                dct["value"] = re.sub(
+                    r"<(.*) object at 0x.*>", r"<\1 object at 0xabcdef>", v
+                )
             return dct
 
         return json.loads(generated_appmap, object_hook=normalize)
